@@ -15,6 +15,11 @@ class JobScheduler:
         pass
 
     def start(self):
+        logger.info("start")
+        subprocess.check_output(
+            'nohup notejob _satrt >>logs/notejob/notejob-run-$(date +%Y-%m-%d).log 2>&1 &', shell=True)
+
+    def _start(self):
         logger.info("start")
         start()
 
@@ -48,6 +53,8 @@ def notejob():
     job = JobScheduler()
     if args.command == 'run':
         job.start()
+    elif args.command == '_start':
+        job._start()
     elif args.command == 'start':
         job.start()
     elif args.command == 'stop':
