@@ -44,16 +44,17 @@ def my_listener(event):
 
 
 def start():
-    #scheduler = BlockingScheduler(jobstores=job_stores, executors=executors, job_defaults=job_defaults)
-    scheduler = BackgroundScheduler(
+    scheduler = BlockingScheduler(
         jobstores=job_stores, executors=executors, job_defaults=job_defaults)
+    # scheduler = BackgroundScheduler(
+    #    jobstores=job_stores, executors=executors, job_defaults=job_defaults)
 
     scheduler.add_job(watch_product,  'interval', seconds=120, args=['44434'])
     scheduler.add_job(watch_product,  'interval', seconds=120, args=['44435'])
-    print(
-        'Press Ctrl+{0} to exit'.format('Break' if os.name == 'nt' else 'C    '))
 
     try:
         scheduler.start()
+        print(scheduler.state)
+        #a = 1
     except (KeyboardInterrupt, SystemExit):
         pass
